@@ -187,10 +187,42 @@ basemaps = Bunch(
             attribution = 'Imagery provided by services from the Global Imagery Browse Services (GIBS), operated by the NASA/GSFC/Earth Science Data and Information System (<a href="https://earthdata.nasa.gov">ESDIS</a>) with funding provided by NASA/HQ.',
             name = 'BASAGIBS.ViirsEarthAtNight2012'
         )
+    ),
+    Strava = Bunch(
+        All = dict(
+            url = 'https://heatmap-external-a.strava.com//tiles/all/hot/{z}/{x}/{y}.png?v=19',
+            max_zoom = 15,
+            attribution = 'href="https://labs.strava.com/heatmap">Strava 2017</a>',
+            name = 'Strava.All'
+        ),
+        Ride = dict(
+            url = 'https://heatmap-external-a.strava.com//tiles/ride/hot/{z}/{x}/{y}.png?v=19',
+            max_zoom = 15,
+            attribution = 'href="https://labs.strava.com/heatmap">Strava 2017</a>',
+            name = 'Strava.Ride'
+        ),
+        Run = dict(
+            url = 'https://heatmap-external-a.strava.com//tiles/run/bluered/{z}/{x}/{y}.png?v=19',
+            max_zoom = 15,
+            attribution = 'href="https://labs.strava.com/heatmap">Strava 2017</a>',
+            name = 'Strava.Run'
+        ),
+        Water = dict(
+            url = 'https://heatmap-external-a.strava.com//tiles/water/blue/{z}/{x}/{y}.png?v=19',
+            max_zoom = 15,
+            attribution = 'href="https://labs.strava.com/heatmap">Strava 2017</a>',
+            name = 'Strava.Water'
+        ),
+        Winter = dict(
+            url = 'https://heatmap-external-a.strava.com//tiles/winter/hot/{z}/{x}/{y}.png?v=19',
+            max_zoom = 15,
+            attribution = 'href="https://labs.strava.com/heatmap">Strava 2017</a>',
+            name = 'Strava.Winter'
+        )
     )
 )
 
-def basemap_to_tiles(bm, day='yesterday'):
+def basemap_to_tiles(bm, day='yesterday', **kwargs):
     # Format the URL with modisdate
     from datetime import date, timedelta
     if day == 'yesterday':
@@ -204,7 +236,8 @@ def basemap_to_tiles(bm, day='yesterday'):
         max_zoom=bm.get('max_zoom', 19),
         min_zoom=bm.get('min_zoom', 1),
         attribution=bm.get('attribution', ''),
-        name=bm.get('name', '')
+        name=bm.get('name', ''),
+        **kwargs
     )
 
 class LayerException(TraitError):
@@ -235,10 +268,11 @@ class Layer(Widget, InteractMixin):
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     name = Unicode().tag(sync=True)
+    base = Bool().tag(sync=True)
 
     bottom = Bool().tag(sync=True)
     options = List(trait=Unicode).tag(sync=True)
-    opacity = Float(min=0.0, max=1.0).tag(sync=True)
+    opacity = Float(1.0, min=0.0, max=1.0).tag(sync=True)
 
     @default('options')
     def _default_options(self):
@@ -517,8 +551,6 @@ class LayersControl(Control):
     _view_name = Unicode('LeafletLayersControlView').tag(sync=True)
     _model_name = Unicode('LeafletLayersControlModel').tag(sync=True)
 
-    overlays = Dict().tag(sync=True, **widget_serialization)
-    base_layers = Dict().tag(sync=True, **widget_serialization)
 
 class DrawControl(Control):
     _view_name = Unicode('LeafletDrawControlView').tag(sync=True)
@@ -629,11 +661,44 @@ class Map(DOMWidget, InteractMixin):
     def _default_options(self):
         return [name for name in self.traits(o=True)]
 
+    _south = Float(def_loc[0]).tag(sync=True)
+    _north = Float(def_loc[0]).tag(sync=True)
+    _east = Float(def_loc[1]).tag(sync=True)
+    _west = Float(def_loc[1]).tag(sync=True)
+
     default_tiles = Instance(TileLayer, allow_none=True).tag(sync=True, **widget_serialization)
 
     @default('default_tiles')
     def _default_tiles(self):
-        return basemap_to_tiles(self.basemap, self.modisdate)
+        return basemap_to_tiles(self.basemap, self.modisdate, base=True)
+
+    @property
+    def north(self):
+        return self._north
+
+    @property
+    def south(self):
+        return self._south
+
+    @property
+    def east(self):
+        return self._east
+
+    @property
+    def west(self):
+        return self._west
+
+    @property
+    def bounds_polygon(self):
+        return [(self.north, self.west),
+                (self.north, self.east),
+                (self.south, self.east),
+                (self.south, self.west)]
+      
+    @property     
+    def bounds(self):
+        return [(self.south, self.west),
+                (self.north, self.east)]
 
     def __init__(self, **kwargs):
         super(Map, self).__init__(**kwargs)
